window.Gleam.initSearch([{"doc":"verify","title":"verify","content":"# verify\nErgonomic data validation library inspired by decode!\n\n[![Package Version](https://img.shields.io/hexpm/v/verify)](https://hex.pm/packages/verify)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/verify/)\n\n```sh\ngleam add verify\n```\n## Examples\n### Simple Usage\n```gleam\nimport verify\n\npub fn main() {\n  let data = &quot;hello, world&quot;\n  let verifier = {\n    use &lt;- verify.string_min_length(5)\n    use &lt;- verify.string_max_length(32)\n    verify.finalize()\n  }\n\n  verify.run(data, verifier)\n}\n```\n### Writing Your Own Custom Verifier\n```gleam\nimport verify\nimport gleam/result\nimport gleam/list\n\npub type Item {\n  Item(name: String, count: Int)\n}\n\npub fn main() {\n  let item = Item(&quot;bread&quot;, 20)\n  let verifier = {\n    use &lt;- verify.custom(verify_item)\n    verify.finalize()\n  }\n\n  verify.run(item, verifier)\n}\n\n\nfn verify_item(item: Item) -&gt; Result(Nil, List(String)) {\n  let name_verifier = {\n    use &lt;- verify.string_not_empty\n    verify.finalize()\n  }\n\n  let count_verifier = {\n    use &lt;- verify.int_min_value(0)\n    verify.finalize()\n  }\n\n  let name_result = verify.run(item.name, name_verifier)\n  let count_result = verify.run(item.count, count_verifier)\n\n  let errors = result.partition([name_result, count_result]).1\n  case errors {\n    [] -&gt; Ok(Nil)\n    _ -&gt; Error(list.flatten(errors))\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/verify&gt;.\n","url":"index.html"},{"doc":"verify","title":"Verifier","content":"pub opaque type Verifier(t)\n A verifier is a value that can be used to test a set of rules\n against a piece of data passed into it.\n\n Verifiers are easily combined to allow large rule sets to be\n used for more complex data requirements.\n\nSynonyms:\nverify.Verifier\nverify Verifier","url":"verify.html#Verifier"},{"doc":"verify","title":"custom","content":"pub fn custom(\n  function: fn(a) -&gt; Result(Nil, List(String)),\n  next: fn() -&gt; Verifier(a),\n) -&gt; Verifier(a)\n Creates a custom verifier. Pass in a function that returns Ok(Nil) on success,\n or a list of error messages on failure.\nSynonyms:\nverify.custom\nverify custom","url":"verify.html#custom"},{"doc":"verify","title":"finalize","content":"pub fn finalize() -&gt; Verifier(a)\n Finalize a verifier.\nSynonyms:\nverify.finalize\nverify finalize","url":"verify.html#finalize"},{"doc":"verify","title":"float_divisible_by","content":"pub fn float_divisible_by(\n  divisor: Float,\n  next: fn() -&gt; Verifier(Float),\n) -&gt; Verifier(Float)\n Verifies that a float is divisible by a given divisor. May not always work\n as expected, due to floating point inaccuracies, use at your own discretion.\nSynonyms:\nverify.float_divisible_by\nverify float_divisible_by","url":"verify.html#float_divisible_by"},{"doc":"verify","title":"float_equal_to","content":"pub fn float_equal_to(\n  compare_to: Float,\n  next: fn() -&gt; Verifier(Float),\n) -&gt; Verifier(Float)\n Verifies that a float is equal to a given value.\nSynonyms:\nverify.float_equal_to\nverify float_equal_to","url":"verify.html#float_equal_to"},{"doc":"verify","title":"float_max_value","content":"pub fn float_max_value(\n  value: Float,\n  next: fn() -&gt; Verifier(Float),\n) -&gt; Verifier(Float)\n Verifies that a float is at most a given value.\nSynonyms:\nverify.float_max_value\nverify float_max_value","url":"verify.html#float_max_value"},{"doc":"verify","title":"float_min_value","content":"pub fn float_min_value(\n  value: Float,\n  next: fn() -&gt; Verifier(Float),\n) -&gt; Verifier(Float)\n Verifies that a float is at least a given value.\nSynonyms:\nverify.float_min_value\nverify float_min_value","url":"verify.html#float_min_value"},{"doc":"verify","title":"float_not_equal_to","content":"pub fn float_not_equal_to(\n  compare_to: Float,\n  next: fn() -&gt; Verifier(Float),\n) -&gt; Verifier(Float)\n Verifies that a float is not equal to a given value.\nSynonyms:\nverify.float_not_equal_to\nverify float_not_equal_to","url":"verify.html#float_not_equal_to"},{"doc":"verify","title":"float_value_range","content":"pub fn float_value_range(\n  min_value: Float,\n  max_value: Float,\n  next: fn() -&gt; Verifier(Float),\n) -&gt; Verifier(Float)\n Verifies that a float has a value that falls within a given inclusive range of values.\nSynonyms:\nverify.float_value_range\nverify float_value_range","url":"verify.html#float_value_range"},{"doc":"verify","title":"int_divisible_by","content":"pub fn int_divisible_by(\n  divisor: Int,\n  next: fn() -&gt; Verifier(Int),\n) -&gt; Verifier(Int)\n Verifies that an int is divisible by a given divisor.\nSynonyms:\nverify.int_divisible_by\nverify int_divisible_by","url":"verify.html#int_divisible_by"},{"doc":"verify","title":"int_equal_to","content":"pub fn int_equal_to(\n  compare_to: Int,\n  next: fn() -&gt; Verifier(Int),\n) -&gt; Verifier(Int)\n Verifies that an int is equal to a given value.\nSynonyms:\nverify.int_equal_to\nverify int_equal_to","url":"verify.html#int_equal_to"},{"doc":"verify","title":"int_max_value","content":"pub fn int_max_value(\n  value: Int,\n  next: fn() -&gt; Verifier(Int),\n) -&gt; Verifier(Int)\n Verifies that an integer is at most a given value.\nSynonyms:\nverify.int_max_value\nverify int_max_value","url":"verify.html#int_max_value"},{"doc":"verify","title":"int_min_value","content":"pub fn int_min_value(\n  value: Int,\n  next: fn() -&gt; Verifier(Int),\n) -&gt; Verifier(Int)\n Verifies that an integer is at least a given value.\nSynonyms:\nverify.int_min_value\nverify int_min_value","url":"verify.html#int_min_value"},{"doc":"verify","title":"int_not_equal_to","content":"pub fn int_not_equal_to(\n  compare_to: Int,\n  next: fn() -&gt; Verifier(Int),\n) -&gt; Verifier(Int)\n Verifies that an int is not equal to a given range of values.\nSynonyms:\nverify.int_not_equal_to\nverify int_not_equal_to","url":"verify.html#int_not_equal_to"},{"doc":"verify","title":"int_value_range","content":"pub fn int_value_range(\n  min_value: Int,\n  max_value: Int,\n  next: fn() -&gt; Verifier(Int),\n) -&gt; Verifier(Int)\n Verifies that an integer has a value that falls within a given inclusive range of values.\nSynonyms:\nverify.int_value_range\nverify int_value_range","url":"verify.html#int_value_range"},{"doc":"verify","title":"run","content":"pub fn run(\n  data: a,\n  verifier: Verifier(a),\n) -&gt; Result(Nil, List(String))\n Run a verifier against a piece of data, returning a result containing\n either the data that was passed in, or a list of error messages from\n failed validations.\nSynonyms:\nverify.run\nverify run","url":"verify.html#run"},{"doc":"verify","title":"string_allowed_characters","content":"pub fn string_allowed_characters(\n  characters: List(String),\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a string contains only a set of allowed characters.\nSynonyms:\nverify.string_allowed_characters\nverify string_allowed_characters","url":"verify.html#string_allowed_characters"},{"doc":"verify","title":"string_contains","content":"pub fn string_contains(\n  substring: String,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a string contains a given substring.\nSynonyms:\nverify.string_contains\nverify string_contains","url":"verify.html#string_contains"},{"doc":"verify","title":"string_disallowed_characters","content":"pub fn string_disallowed_characters(\n  characters: List(String),\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a string does not contain a set of disallowed characters\nSynonyms:\nverify.string_disallowed_characters\nverify string_disallowed_characters","url":"verify.html#string_disallowed_characters"},{"doc":"verify","title":"string_does_not_contain","content":"pub fn string_does_not_contain(\n  substring: String,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a string does not contain a given substring.\nSynonyms:\nverify.string_does_not_contain\nverify string_does_not_contain","url":"verify.html#string_does_not_contain"},{"doc":"verify","title":"string_ends_with","content":"pub fn string_ends_with(\n  end: String,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a string ends with a given string.\nSynonyms:\nverify.string_ends_with\nverify string_ends_with","url":"verify.html#string_ends_with"},{"doc":"verify","title":"string_equal_to","content":"pub fn string_equal_to(\n  compare_to: String,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a string is equal to a given string.\nSynonyms:\nverify.string_equal_to\nverify string_equal_to","url":"verify.html#string_equal_to"},{"doc":"verify","title":"string_exact_length","content":"pub fn string_exact_length(\n  length: Int,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a strings length is exactly the given length.\nSynonyms:\nverify.string_exact_length\nverify string_exact_length","url":"verify.html#string_exact_length"},{"doc":"verify","title":"string_length_range","content":"pub fn string_length_range(\n  min_length: Int,\n  max_length: Int,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a strings length falls within a given inclusive range.\nSynonyms:\nverify.string_length_range\nverify string_length_range","url":"verify.html#string_length_range"},{"doc":"verify","title":"string_max_length","content":"pub fn string_max_length(\n  length: Int,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a strings length is at most the given length. The max length value is inclusive.\nSynonyms:\nverify.string_max_length\nverify string_max_length","url":"verify.html#string_max_length"},{"doc":"verify","title":"string_min_length","content":"pub fn string_min_length(\n  length: Int,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that strings length is at least the given length.\nSynonyms:\nverify.string_min_length\nverify string_min_length","url":"verify.html#string_min_length"},{"doc":"verify","title":"string_not_empty","content":"pub fn string_not_empty(\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a string is not empty.\nSynonyms:\nverify.string_not_empty\nverify string_not_empty","url":"verify.html#string_not_empty"},{"doc":"verify","title":"string_not_equal_to","content":"pub fn string_not_equal_to(\n  compare_to: String,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a string is not equal to a given string.\nSynonyms:\nverify.string_not_equal_to\nverify string_not_equal_to","url":"verify.html#string_not_equal_to"},{"doc":"verify","title":"string_starts_with","content":"pub fn string_starts_with(\n  start: String,\n  next: fn() -&gt; Verifier(String),\n) -&gt; Verifier(String)\n Verifies that a string starts with a given string.\nSynonyms:\nverify.string_starts_with\nverify string_starts_with","url":"verify.html#string_starts_with"},{"doc":"verify","title":"verify","content":" Based on the [decode](https://hexdocs.pm/decode/) library, `verify`\n provides an easy, composable way to validate data.\n\n # Examples\n ```gleam\n let str = &quot;hello, world&quot;\n let verifier = {\n    use &lt;- verify.string_min_length(2)\n    use &lt;- verify.string_max_length(32)\n    verify.finalize()\n }\n\n let result = verify.run(str, verifier)\n assert result == Ok(str)\n ```","url":"verify.html"}]);